%define anolis_release 3
%bcond_with lint
%bcond_without tests
%bcond_with mageia
%define debug_package %{nil}
%global mockgid 135
%global __python %{__python3}
%global python_sitelib %{python3_sitelib}

Name: 		mock
Summary:	Builds packages inside chroots
Version: 	3.5
Release:	%{anolis_release}%{?dist}
License: 	GPL-2.0-or-later
URL: 		https://github.com/rpm-software-management/mock/
Source0: 	%{name}-%{version}.tar.gz
Source1: 	anolis-os-23-x86_64.cfg	
Source2: 	anolis-os-23-aarch64.cfg
Source3: 	anolis-os-23-loongarch64.cfg

BuildRequires: perl-interpreter bash-completion python3-devel
%if %{with lint}
BuildRequires: python3-pylint
%endif
%if %{with tests}
BuildRequires: python3-distro python3-jinja2 python3-pyroute2
BuildRequires: python3-pytest python3-requests python3-templated-dictionary
%endif

Requires: tar pigz createrepo_c mock-filesystem
Requires: usermode systemd systemd-container coreutils
Requires: python3-distro python3-jinja2 python3-requests
Requires: python3-rpm python3-pyroute2 python3-templated-dictionary
Requires: dnf dnf-plugins-core util-linux coreutils procps-ng
Requires: distribution-gpg-keys

Recommends: btrfs-progs dnf-utils

Suggests: qemu-user-static procenv podman yum iproute

Conflicts: mock-core-configs < 33

%description
Mock takes an SRPM and builds it in a chroot.

%package scm
Summary: Mock SCM integration module
Requires: %{name} = %{version}-%{release}
Recommends: cvs git subversion tar rpkg

%description scm
Mock SCM integration module.

%package lvm
Summary: LVM plugin for mock
Requires: lvm2 %{name} = %{version}-%{release}

%description lvm
Mock plugin that enables using LVM as a backend and support creating snapshots
of the buildroot.

%package filesystem
Summary:  Mock filesystem layout
Requires(pre):  shadow-utils

%description filesystem
Filesystem layout and group for Mock.

%prep
%autosetup -n %{name}-%{version} -p1

%build
for i in py/mockbuild/constants.py py/mock-parse-buildlog.py; do
    perl -p -i -e 's|^VERSION\s*=.*|VERSION="%{version}"|' $i
    perl -p -i -e 's|^SYSCONFDIR\s*=.*|SYSCONFDIR="%{_sysconfdir}"|' $i
    perl -p -i -e 's|^PYTHONDIR\s*=.*|PYTHONDIR="%{python_sitelib}"|' $i
    perl -p -i -e 's|^PKGPYTHONDIR\s*=.*|PKGPYTHONDIR="%{python_sitelib}/mockbuild"|' $i
done
for i in docs/mock.1 docs/mock-parse-buildlog.1; do
    perl -p -i -e 's|\@VERSION\@|%{version}"|' $i
done

%install
mkdir -p %{buildroot}%{_sysconfdir}/mock/eol/templates
mkdir -p %{buildroot}%{_sysconfdir}/mock/templates
install -d %{buildroot}%{_bindir}
install -d %{buildroot}%{_libexecdir}/mock
install mockchain %{buildroot}%{_bindir}/mockchain
install py/mock-parse-buildlog.py %{buildroot}%{_bindir}/mock-parse-buildlog
install py/mock.py %{buildroot}%{_libexecdir}/mock/mock
ln -s consolehelper %{buildroot}%{_bindir}/mock
install create_default_route_in_container.sh %{buildroot}%{_libexecdir}/mock/
install -d %{buildroot}%{_sysconfdir}/pam.d
cp -a etc/pam/* %{buildroot}%{_sysconfdir}/pam.d/
install -d %{buildroot}%{_sysconfdir}/mock
cp -a etc/mock/* %{buildroot}%{_sysconfdir}/mock/
install -d %{buildroot}%{_sysconfdir}/security/console.apps/
cp -a etc/consolehelper/mock %{buildroot}%{_sysconfdir}/security/console.apps/%{name}
install -d %{buildroot}%{_datadir}/bash-completion/completions/
cp -a etc/bash_completion.d/* %{buildroot}%{_datadir}/bash-completion/completions/
ln -s mock %{buildroot}%{_datadir}/bash-completion/completions/mock-parse-buildlog
install -d %{buildroot}%{_sysconfdir}/pki/mock
cp -a etc/pki/* %{buildroot}%{_sysconfdir}/pki/mock/
install -d %{buildroot}%{python_sitelib}/
cp -a py/mockbuild %{buildroot}%{python_sitelib}/

install -d %{buildroot}%{_mandir}/man1
cp -a docs/mock.1 docs/mock-parse-buildlog.1 %{buildroot}%{_mandir}/man1/
install -d %{buildroot}%{_datadir}/cheat
cp -a docs/mock.cheat %{buildroot}%{_datadir}/cheat/mock

install -d %{buildroot}/var/lib/mock
install -d %{buildroot}/var/cache/mock

mkdir -p %{buildroot}%{_pkgdocdir}
install -p -m 0644 docs/site-defaults.cfg %{buildroot}%{_pkgdocdir}

sed -i 's/^_MOCK_NVR = None$/_MOCK_NVR = "%name-%version-%release"/' \
    %{buildroot}%{_libexecdir}/mock/mock

pushd %{buildroot}%{_sysconfdir}/mock
install -m 0644 %{SOURCE1} templates/
install -m 0644 %{SOURCE2} templates/
install -m 0644 %{SOURCE3} templates/
ln -sf templates/anolis-os-23-%{_arch}.cfg default.cfg
popd

%pre filesystem
getent group mock > /dev/null || groupadd -f -g %mockgid -r mock
exit 0

%check
%if %{with lint}
pylint-3 py/mockbuild/ py/*.py py/mockbuild/plugins/* || :
%endif

%if %{with tests}
./run-tests.sh --no-cov
%endif

%files
%defattr(0644, root, mock)
%doc %{_pkgdocdir}/site-defaults.cfg
%{_datadir}/bash-completion/completions/mock
%{_datadir}/bash-completion/completions/mock-parse-buildlog
%defattr(-, root, root)
# executables
%{_bindir}/mock
%{_bindir}/mockchain
%{_bindir}/mock-parse-buildlog
%{_libexecdir}/mock
%{python_sitelib}/*
%exclude %{python_sitelib}/mockbuild/scm.*
%exclude %{python_sitelib}/mockbuild/__pycache__/scm.*
%exclude %{python_sitelib}/mockbuild/plugins/lvm_root.*
%exclude %{python_sitelib}/mockbuild/plugins/__pycache__/lvm_root.*
%config(noreplace) %{_sysconfdir}/%{name}/*.ini
%config(noreplace) %{_sysconfdir}/pam.d/%{name}
%config(noreplace) %{_sysconfdir}/security/console.apps/%{name}
%dir %{_sysconfdir}/pki/mock
%config(noreplace) %{_sysconfdir}/pki/mock/*
%{_mandir}/man1/mock.1*
%{_mandir}/man1/mock-parse-buildlog.1*
%{_datadir}/cheat/mock
%defattr(0775, root, mock, 0775)
%dir %{_localstatedir}/cache/mock
%dir %{_localstatedir}/lib/mock
%config(noreplace) %{_sysconfdir}/mock/default.cfg
%config(noreplace) %{_sysconfdir}/mock/templates/anolis-os-23-x86_64.cfg
%config(noreplace) %{_sysconfdir}/mock/templates/anolis-os-23-aarch64.cfg
%config(noreplace) %{_sysconfdir}/mock/templates/anolis-os-23-loongarch64.cfg

%files scm
%{python_sitelib}/mockbuild/scm.py*
%{python3_sitelib}/mockbuild/__pycache__/scm.*.py*

%files lvm
%{python_sitelib}/mockbuild/plugins/lvm_root.*
%{python3_sitelib}/mockbuild/plugins/__pycache__/lvm_root.*.py*

%files filesystem
%license COPYING
%dir  %{_sysconfdir}/mock
%dir  %{_sysconfdir}/mock/eol
%dir  %{_sysconfdir}/mock/eol/templates
%dir  %{_sysconfdir}/mock/templates
%dir  %{_datadir}/cheat

%changelog
* Wed Aug 16 2023 Wenlong Zhang <zhangwenlong@loongson.cn> - 3.5-3
- add cfg files for loongarch64

* Fri Apr 21 2023 happy_orange <songnannan@linux.alibaba.com> - 3.5-2
- change the cfg files

* Fri Apr 21 2023 happy_orange <songnannan@linux.alibaba.com> - 3.5-1
- package init
